# Generated by roxygen2: do not edit by hand

S3method(coef,dsr_4pl)
S3method(fitted,dsr_4pl)
S3method(predict,dsr_4pl)
S3method(print,dsr_4pl)
S3method(residuals,dsr_4pl)
export(annotate_hit_info)
export(apply_plate_layout)
export(baseline_subtract)
export(build_auc_matrix)
export(calc_cv)
export(calc_drc_auc)
export(calc_plate_qc)
export(calc_replicate_correlation)
export(calc_replicate_cv)
export(calc_robust_z_prime)
export(calc_sb_ratio)
export(calc_sn_ratio)
export(calc_ssmd)
export(calc_well_zscore)
export(calc_z_factor)
export(calc_z_prime)
export(calculate_qc_metrics)
export(check_control_label)
export(clean_compound_id)
export(clean_filename)
export(cluster_auc_matrix)
export(compute_auc)
export(compute_delta_auc)
export(convert_conc_log10)
export(detect_outlier_wells)
export(export_hit_table)
export(extract_cluster_hit)
export(extract_drc_params)
export(filter_bad_replicate)
export(filter_low_quality_curve)
export(filter_valid_plates)
export(fit_4pl_curve)
export(fit_dose_response)
export(flag_qc_plates)
export(four_pl)
export(generate_hts_report)
export(hts_pal)
export(import_dose_response)
export(merge_plate_data)
export(norm_by_control)
export(plate_layout)
export(plate_layout_1536)
export(plate_layout_384)
export(plot_auc_heatmap)
export(plot_batch_drc_overlay)
export(plot_cluster_tree)
export(plot_condition_scatter)
export(plot_control_scatter)
export(plot_cv_distribution)
export(plot_delta_auc_heatmap)
export(plot_dose_response_curves)
export(plot_hit_bar_count)
export(plot_hit_stratify_bar)
export(plot_ic50_auc_cor)
export(plot_inhibition_hist)
export(plot_plate_heatmap)
export(plot_plate_heatmap_inhibition)
export(plot_plate_heatmap_raw)
export(plot_plate_qc)
export(plot_primary_inhibition_rank)
export(plot_primary_secondary_cor)
export(plot_qc_boxplot)
export(plot_qc_circular_heatmap)
export(plot_qc_metric_circular)
export(plot_qc_metric_trend)
export(plot_replicate_scatter)
export(plot_sigma_hits)
export(plot_single_drc)
export(rank_hit_compound)
export(read_hts_plate)
export(read_plate_layout)
export(select_hits_cutoff)
export(select_hits_sigma)
export(select_primary_hit)
export(select_sigma_hits)
export(summarize_plate_setup)
export(summarize_primary_hit)
export(summarize_sigma_hits)
export(theme_hts)
export(windows_to_linux_path)
importFrom(rlang,.data)
