% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{clean_filename}
\alias{clean_filename}
\title{Sanitise a string for use as a file name}
\usage{
clean_filename(filename_str)
}
\arguments{
\item{filename_str}{A character vector of candidate file names.}
}
\value{
A character vector with newlines removed, \code{/} and \code{:} replaced by
\verb{_} and \code{-} respectively, and the characters \verb{* ? " < > |} stripped.
}
\description{
Removes newlines and characters that are illegal in file names on common
operating systems, so that drug names or plate labels can be turned into safe
output file names.
}
\examples{
clean_filename("Drug A/B: 10\u00b5M?")

}
