% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/module5_drc.R
\name{plot_single_drc}
\alias{plot_single_drc}
\title{Plot a single dose-response curve}
\usage{
plot_single_drc(drc, curve_id = NULL, color = "#0072B2")
}
\arguments{
\item{drc}{An \code{hts_drc} object (ideally after \code{\link[=calc_drc_auc]{calc_drc_auc()}}).}

\item{curve_id}{Curve identifier (from \code{drc$meta$curve_id}). Defaults to the
first curve.}

\item{color}{Curve colour. Default \code{"#0072B2"}.}
}
\value{
A \link[ggplot2:ggplot]{ggplot2::ggplot} object.
}
\description{
Plots one compound's observed points and fitted 4PL curve on a log10
concentration axis, annotating IC50, AUC and \eqn{R^2}.
}
\examples{
drc <- calc_drc_auc(fit_4pl_curve(import_dose_response(hts_dose_response,
  response_col = "viability", group_cols = "cell_line"),
  group_cols = "cell_line"))
plot_single_drc(drc, drc$meta$curve_id[1])

}
\seealso{
\code{\link[=plot_batch_drc_overlay]{plot_batch_drc_overlay()}}
}
