% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/module7_report.R
\name{plot_hit_stratify_bar}
\alias{plot_hit_stratify_bar}
\title{Stratified hit-count bar chart}
\usage{
plot_hit_stratify_bar(ranked)
}
\arguments{
\item{ranked}{A data frame from \code{\link[=rank_hit_compound]{rank_hit_compound()}} with a \code{tier} column.}
}
\value{
A \link[ggplot2:ggplot]{ggplot2::ggplot} object.
}
\description{
Bar chart of the number of Strong, Moderate and Weak hits.
}
\examples{
drc <- calc_drc_auc(fit_4pl_curve(import_dose_response(hts_dose_response,
  response_col = "viability", group_cols = "cell_line"),
  group_cols = "cell_line"))
params <- merge(extract_drc_params(drc), drc$meta[, c("curve_id", "auc")])
plot_hit_stratify_bar(rank_hit_compound(params))

}
\seealso{
\code{\link[=rank_hit_compound]{rank_hit_compound()}}
}
