% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/module7_report.R
\name{export_hit_table}
\alias{export_hit_table}
\title{Export a hit summary table}
\usage{
export_hit_table(hits, file, ...)
}
\arguments{
\item{hits}{A hit data frame.}

\item{file}{Output path.}

\item{...}{Passed to \code{\link[utils:write.csv]{utils::write.csv()}}.}
}
\value{
The \code{file} path, invisibly.
}
\description{
Writes a complete hit table (all QC and pharmacology columns) to a CSV file.
}
\examples{
drc <- calc_drc_auc(fit_4pl_curve(import_dose_response(hts_dose_response,
  response_col = "viability", group_cols = "cell_line"),
  group_cols = "cell_line"))
params <- merge(extract_drc_params(drc), drc$meta[, c("curve_id", "auc")])
export_hit_table(rank_hit_compound(params), tempfile(fileext = ".csv"))

}
\seealso{
\code{\link[=rank_hit_compound]{rank_hit_compound()}}, \code{\link[=annotate_hit_info]{annotate_hit_info()}}
}
