% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/module2_norm.R
\name{plot_plate_heatmap_inhibition}
\alias{plot_plate_heatmap_inhibition}
\title{Percent-inhibition plate heatmap}
\usage{
plot_plate_heatmap_inhibition(hts_norm, plate = NULL, value = "inhibition")
}
\arguments{
\item{hts_norm}{An \code{hts_norm} object from \code{\link[=norm_by_control]{norm_by_control()}}.}

\item{plate}{Plate identifier to show. Defaults to the first plate.}

\item{value}{Name of the value column to colour by. Default \code{"inhibition"}.}
}
\value{
A \link[ggplot2:ggplot]{ggplot2::ggplot} object.
}
\description{
Draws a plate's normalised percent-inhibition values in plate layout. A thin
wrapper around \code{\link[=plot_plate_heatmap]{plot_plate_heatmap()}} for \code{hts_norm} objects.
}
\examples{
norm <- norm_by_control(baseline_subtract(read_hts_plate(hts_primary_raw)))
plot_plate_heatmap_inhibition(norm, plate = "P01")

}
\seealso{
\code{\link[=plot_plate_heatmap]{plot_plate_heatmap()}}, \code{\link[=plot_inhibition_hist]{plot_inhibition_hist()}}
}
