% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/module4_primary.R
\name{plot_hit_bar_count}
\alias{plot_hit_bar_count}
\title{Hit-count bar chart}
\usage{
plot_hit_bar_count(hits)
}
\arguments{
\item{hits}{A data frame from \code{\link[=select_primary_hit]{select_primary_hit()}}.}
}
\value{
A \link[ggplot2:ggplot]{ggplot2::ggplot} object.
}
\description{
Bar chart of the number of hit versus non-hit compounds from a primary
screen.
}
\examples{
norm <- norm_by_control(baseline_subtract(read_hts_plate(hts_primary_raw)))
plot_hit_bar_count(select_primary_hit(norm))

}
\seealso{
\code{\link[=summarize_primary_hit]{summarize_primary_hit()}}
}
