% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/module6_auc_matrix.R
\name{plot_cluster_tree}
\alias{plot_cluster_tree}
\title{Plot the compound clustering dendrogram}
\usage{
plot_cluster_tree(cluster_result, main = "Compound clustering")
}
\arguments{
\item{cluster_result}{The list returned by \code{\link[=cluster_auc_matrix]{cluster_auc_matrix()}}.}

\item{main}{Plot title. Default \code{"Compound clustering"}.}
}
\value{
Invisibly \code{NULL}; called for its side effect (a base-graphics plot).
}
\description{
Draws the hierarchical clustering tree of compounds from an AUC matrix.
}
\examples{
drc <- calc_drc_auc(fit_4pl_curve(import_dose_response(hts_dose_response,
  response_col = "viability", group_cols = "cell_line"),
  group_cols = "cell_line"))
m <- build_auc_matrix(drc$meta)
plot_cluster_tree(cluster_auc_matrix(m, k = 2))

}
\seealso{
\code{\link[=cluster_auc_matrix]{cluster_auc_matrix()}}
}
