% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/module4_primary.R
\name{summarize_primary_hit}
\alias{summarize_primary_hit}
\title{Summarise primary-screen hits}
\usage{
summarize_primary_hit(hits)
}
\arguments{
\item{hits}{A data frame from \code{\link[=select_primary_hit]{select_primary_hit()}}.}
}
\value{
A one-row data frame with \code{n_compounds}, \code{n_hits}, \code{hit_rate}
(fraction) and \code{cutoff}.
}
\description{
Reports the number of compounds screened, the number of hits and the hit
rate.
}
\examples{
norm <- norm_by_control(baseline_subtract(read_hts_plate(hts_primary_raw)))
summarize_primary_hit(select_primary_hit(norm))

}
\seealso{
\code{\link[=select_primary_hit]{select_primary_hit()}}
}
